@@ -1,6 +1,7 @@
 from injectable.autowiring.autowired_type import Autowired
 from injectable.autowiring.autowired_decorator import autowired
 from injectable.container.injection_container import InjectionContainer
+from injectable.injection.injectable_factory_decorator import injectable_factory
 from injectable.injection.inject import inject, inject_multiple
 from injectable.injection.injectable_decorator import injectable
 from injectable import errors
@@ -9,6 +10,7 @@ __all__ = [
     "InjectionContainer",
     "autowired",
     "Autowired",
+    "injectable_factory",
     "injectable",
     "inject",
     "inject_multiple",
